@@ -1,133 +1,5 @@
 r'''
-# aws-sns-lambda module
-
-<!--BEGIN STABILITY BANNER-->---
-
-
-![Stability: Stable](https://img.shields.io/badge/cfn--resources-stable-success.svg?style=for-the-badge)
-
----
-<!--END STABILITY BANNER-->
-
-| **Reference Documentation**:| <span style="font-weight: normal">https://docs.aws.amazon.com/solutions/latest/constructs/</span>|
-|:-------------|:-------------|
-
-<div style="height:8px"></div>
-
-| **Language**     | **Package**        |
-|:-------------|-----------------|
-|![Python Logo](https://docs.aws.amazon.com/cdk/api/latest/img/python32.png) Python|`aws_solutions_constructs.aws_sns_lambda`|
-|![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-sns-lambda`|
-|![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.snslambda`|
-
-## Overview
-
-This AWS Solutions Construct implements an Amazon SNS connected to an AWS Lambda function.
-
-Here is a minimal deployable pattern definition:
-
-Typescript
-
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { SnsToLambda, SnsToLambdaProps } from "@aws-solutions-constructs/aws-sns-lambda";
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-
-new SnsToLambda(this, 'test-sns-lambda', {
-  lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_20_X,
-    handler: 'index.handler',
-    code: lambda.Code.fromAsset(`lambda`)
-  }
-});
-```
-
-Python
-
-```python
-from aws_solutions_constructs.aws_sns_lambda import SnsToLambda
-from aws_cdk import (
-    aws_lambda as _lambda,
-    Stack
-)
-from constructs import Construct
-
-SnsToLambda(self, 'test_sns_lambda',
-            lambda_function_props=_lambda.FunctionProps(
-                code=_lambda.Code.from_asset('lambda'),
-                runtime=_lambda.Runtime.PYTHON_3_11,
-                handler='index.handler'
-            )
-            )
-```
-
-Java
-
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.snslambda.*;
-
-new SnsToLambda(this, "test-lambda-sqs-stack", new SnsToLambdaProps.Builder()
-        .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_20_X)
-                .code(Code.fromAsset("lambda"))
-                .handler("index.handler")
-                .build())
-        .build());
-```
-
-## Pattern Construct Props
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
-|existingTopicObj?|[`sns.Topic`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Existing instance of SNS Topic object, providing both this and `topicProps` will cause an error.|
-|topicProps?|[`sns.TopicProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sns.TopicProps.html)|Optional user provided properties to override the default properties for the SNS topic.|
-|enableEncryptionWithCustomerManagedKey?|`boolean`|If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps.|
-|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SNS Topic with.|
-|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html#construct-props)|Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with.|
-
-## Pattern Properties
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Returns an instance of the Lambda function created by the pattern.|
-|snsTopic|[`sns.Topic`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sns.Topic.html)|Returns an instance of the SNS topic created by the pattern.|
-
-## Default settings
-
-Out of the box implementation of the Construct without any override will set the following defaults:
-
-### Amazon SNS Topic
-
-* Configure least privilege access permissions for SNS Topic
-* Enable server-side encryption for SNS Topic using AWS managed KMS Key
-* Enforce encryption of data in transit
-
-### AWS Lambda Function
-
-* Configure limited privilege access IAM role for Lambda function
-* Enable reusing connections with Keep-Alive for NodeJs Lambda function
-* Enable X-Ray Tracing
-* Set Environment Variables
-
-  * AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
-
-## Architecture
-
-![Architecture Diagram](architecture.png)
-
----
-
-
-© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+Documentation for this pattern can be found [here](https://github.com/awslabs/aws-solutions-constructs/blob/main/source/patterns/%40aws-solutions-constructs/aws-sns-lambda/README.adoc)
 '''
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
@@ -195,10 +67,10 @@ class SnsToLambda(
         :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps. Default: - False if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
         :param encryption_key: An optional, imported encryption key to encrypt the SNS Topic with. Default: - None
         :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
-        :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
-        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
-        :param topic_props: Optional user provided properties to override the default properties for the SNS topic. Default: - Default properties are used.
+        :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
+        :param existing_topic_obj: Optional - existing instance of SNS topic object, providing both this and ``topicProps`` will cause an error. Default: - Default props are used
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default properties are used.
+        :param topic_props: Optional - user provided properties to override the default properties for the SNS topic. Providing both this and ``existingTopicObj`` is an error. Default: - Default properties are used.
 
         :access: public
         :since: 0.8.0
@@ -260,10 +132,10 @@ class SnsToLambdaProps:
         :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps. Default: - False if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
         :param encryption_key: An optional, imported encryption key to encrypt the SNS Topic with. Default: - None
         :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
-        :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
-        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
-        :param topic_props: Optional user provided properties to override the default properties for the SNS topic. Default: - Default properties are used.
+        :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
+        :param existing_topic_obj: Optional - existing instance of SNS topic object, providing both this and ``topicProps`` will cause an error. Default: - Default props are used
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default properties are used.
+        :param topic_props: Optional - user provided properties to override the default properties for the SNS topic. Providing both this and ``existingTopicObj`` is an error. Default: - Default properties are used.
 
         :summary: The properties for the SnsToLambda class.
         '''
@@ -335,7 +207,7 @@ class SnsToLambdaProps:
     def existing_lambda_obj(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
-        '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
+        '''Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
@@ -344,7 +216,7 @@ class SnsToLambdaProps:
 
     @builtins.property
     def existing_topic_obj(self) -> typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic]:
-        '''Existing instance of SNS Topic object, providing both this and topicProps will cause an error..
+        '''Optional - existing instance of SNS topic object, providing both this and ``topicProps`` will cause an error.
 
         :default: - Default props are used
         '''
@@ -355,7 +227,9 @@ class SnsToLambdaProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
-        '''User provided props to override the default props for the Lambda function.
+        '''Optional - user provided props to override the default props for the Lambda function.
+
+        Providing both this and ``existingLambdaObj`` is an error.
 
         :default: - Default properties are used.
         '''
@@ -364,7 +238,9 @@ class SnsToLambdaProps:
 
     @builtins.property
     def topic_props(self) -> typing.Optional[_aws_cdk_aws_sns_ceddda9d.TopicProps]:
-        '''Optional user provided properties to override the default properties for the SNS topic.
+        '''Optional - user provided properties to override the default properties for the SNS topic.
+
+        Providing both this and ``existingTopicObj`` is an error.
 
         :default: - Default properties are used.
         '''
